@@ -4,7 +4,7 @@ if (exists("list2DF", envir = baseenv())) {
   f = get("list2DF", envir = baseenv())
   expect_same = makeCompareFun(f, backports:::list2DF)
 
-  x <- list(character(), "A", c("B", "C"))
+  x <- list(c("A", "B"), c("B", "C"))
   n <- lengths(x)
   expect_same(list(x = x, n = n))
 
